@@ -177,8 +177,11 @@ def compute_weights(data, varnames, W_ids, cause_list):
             cause_id = [i for i in range(len(varnames)) if varnames[i] in cause]
             data_beta = data[:, cause_id]
             if 'int' in data.dtype.name:
-                numerator = data_beta[data_beta.min(axis=1) >= 0]
-                denominator = data_beta[(data_beta.min(axis=1) >= 0) & (data[:, varnames.index(ri)] >= 0)]
+                numerator = data_beta[
+                    (data_beta.min(axis=1) >= 0) & (data_beta.max(axis=1) != np.iinfo(data.dtype).max)]
+                denominator = data_beta[
+                    (data_beta.min(axis=1) >= 0) & (data_beta.max(axis=1) != np.iinfo(data.dtype).max) & (
+                                data[:, varnames.index(ri)] >= 0)]
                 arities = np.amax(data_beta, axis=0) + 1
                 f_w = density_counter(numerator, arities).reshape(arities)
                 f_wr = density_counter(denominator, arities).reshape(arities)
